🐙 oktopus
==========
|ci-badge| |cov-badge| |zenodo-badge|

.. |ci-badge| image:: https://travis-ci.org/KeplerGO/oktopus.svg?branch=master
    :target: https://travis-ci.org/KeplerGO/oktopus
.. |cov-badge| image:: https://codecov.io/gh/mirca/oktopus/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/mirca/oktopus/branch/master/
.. |zenodo-badge| image:: https://zenodo.org/badge/84591713.svg
   :target: https://zenodo.org/badge/latestdoi/84591713

A soft-bodied, eight-armed package for beautiful inference.

To install ``oktopus``, run::

    pip install oktopus

or::

    git clone https://github.com/KeplerGO/oktopus.git
    cd oktopus
    pip install -e .

And you're all set!
